@@ -36,11 +36,12 @@ require_once 'model/DateConvert.php';
 require_once 'model/Filter.php';
 require_once 'model/AppState.php';
 
-$authscript  = $App->getConfig('EXTERNAL_AUTH','/usr/sbin/benno_auth.d');
+$authscript     = $App->getConfig('EXTERNAL_AUTH','/usr/sbin/benno_auth.d');
 
-$login = $App->getParam('login',true);
-$userid = $login['username']; // fetch masked parameter (DB access)
-$passwd = $_REQUEST['login']['password']; // fetch PW raw
+$clientTimezone = $App->getParam('clientTimezone');
+$login          = $App->getParam('login',true);
+$userid         = $login['username']; // fetch masked parameter (DB access)
+$passwd         = $_REQUEST['login']['password']; // fetch PW raw
 
 $redata['selectuser'] = $userid;
 if (! $passwd) {
@@ -133,7 +134,9 @@ foreach ($archive_list as $archive) { // disable index counter if subarchives av
 try {
     // searchMask
     $AppState = new AppState($USER->id);
-    $searchMaskState = $AppState->getValue('searchMaskState','Simple');
+    $defaultSearchState = $App->getConfig('DEFAULT_SEARCHMASK','Simple');
+    $searchMaskState = $AppState->getValue('searchMaskState',$defaultSearchState);
+
     $App->setSession('searchMaskState',$searchMaskState);
     $App->setSession('resendMailto',$AppState->getValue('resendMailto'));
 
@@ -170,6 +173,7 @@ $App->setSession('USER',$USER);
 $App->setSession('Backend',$Backend);   // store backend for this session
 $App->setSession('archive',$archive);   // store current archive
 $App->setSession('FilterList',$FilterList);
+$App->setSession('clientTimezone',$clientTimezone);
 
 // set language on change and after login for 32 days
 setcookie("BENNO_LANGUAGE", $LANG, time()+2764800, dirname($_SERVER['REQUEST_URI']));
