@@ -30,6 +30,7 @@
  * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
  * Suite 330, Boston, MA  02111-1307  USA
  */
+require_once 'model/PermaId.php';
 
 
 class EMail
@@ -289,5 +290,16 @@ class EMail
         array_push($this->attachments,$attachment);
     }
 
+
+    /**
+     * Get permalink id for this email
+     */
+    function getPermaId($archive)
+    {
+        $PermaId = new PermaId();
+        return $PermaId->encrypt($this->bennoId,$archive);
+    }
+
+
 }
 ?>
