@@ -32,8 +32,7 @@
  */
 
 $App->setSession('QueryResult',$QueryResult);
-$App->setSession('SimpleQuery',$SimpleQuery);
-$App->setSession('ExtQuery',$ExtQuery);
+$App->setSession('SearchQuery',$SearchQuery);
 $App->setSession('Backend',$Backend);
 $App->setSession('EMail',$EMail);
 
@@ -47,13 +46,16 @@ if ($QueryResult->overall > 0) {
 
 $App->assign('mailCount',$mailCount);
 $App->assign('QueryList',$QueryList);
-$App->assign('QueryResult',$QueryResult);
-$App->assign('SimpleQuery',$SimpleQuery);
-$App->assign('ExtQuery',$ExtQuery);
 $App->assign('Backend',$Backend);
+
+$App->assign('SearchQuery',$QueryResult->getQuery());
+$App->assign('queryData',$queryData);
+
+$App->assign('QueryResult',$QueryResult);
 if ($QueryResult) {
     $App->assign('MailList',$QueryResult->fetchMails());
 }
+
 $App->assign('archive',$archive);
 
 $DummyMail = new EMail('dummy','dummy');
